==> verlof-0.4.5.tar.gz: verlof-0.4.5/src/menu.js <==
/*
 * menu.js - menubar JavaScript.
 *
 * Verlof Web application
 *
 * Copyright (c) 2002, by Leiden University.
 * verlof is free software.  See the file Copying for copying permission.
 *
 * $Revision: 1.4 $
 * $Date: 2003-01-29 09:19:25+01 $
 * $Source: \\\\fwneld\\msdos\\RCS\\K\\fsc\\prj\\verlof\\src\\menu.js,v $
 * %Author: M.J. Moene %
 */

/*
 * $Header: \\\\fwneld\\msdos\\RCS\\K\\fsc\\prj\\verlof\\src\\menu.js,v 1.4 2003-01-29 09:19:25+01 moene Exp $
 *
 * $Log: menu.js,v $
 * Revision 1.4  2003-01-29 09:19:25+01  moene
 * <>
 *
 * Revision 1.3  2003/01/06 11:31:51  moene
 * namefield now also accepts accented letters [\xC0-\xFF].
 *
 * Revision 1.2  2002-12-12 15:59:46+01  moene
 * added more checking for names that can be handled from Menu namefield.
 *
 * Revision 1.1  2002/05/13 09:20:04  moene
 * Initial revision
 *
 */

var newEntryWindow = null;		// the new entry window
var helpWindow	   = null;		// the help window

function initialize()
{
//alert( 'initialize' )
   document.menu.dbhost.value = dbhost
   document.menu.db.value     = db
   document.menu.sort.value   = 'n+1-'	  // name ascending, date1 descending
   document.menu.year.value   = (new Date).getFullYear()

   document.menu.name.value   = getCookie( 'name' )

   document.menu.target       = 'body'
   document.menu.method       = 'post'
   document.menu.action       = submitView
//   document.menu.action     = '/cgi-bin/printenv'

   return false;
}

function finalize()
{
//alert( 'finalize' );

   closeWindow( newEntryWindow );

   return false;
}

function mkYearList()
{
//return '1,2'

   yrlist = document.menu.year.value.split(/[ ,;:]/)

   var s = new String()

   // empty, or '*' acts as wildcard -> return empty string

   if ( yrlist[0].match( /^$|^[\s\*]+$/ ) )
      return s
   else
      return s.join( yrlist, ',' )
}

function mkNameList()
{
//return 'a,b'

   nmlist = document.menu.name.value.split(/[,;:]/)

   var s = new String()

   // empty, or '*' acts as wildcard -> return empty string

   if ( !nmlist[0].match( /^$|\*/ ) )
   {
      var k = 0
      for ( var i = 0; i < nmlist.length; i++ ) {

	 // skip if name cannot be handled by class Name
	 if ( !nmlist[i].match( /^[\s]*[a-zA-Z\xC0-\xFF\(\)\ \._-]+$/ ) )
	    continue

	 n = new Name( nmlist[i] )
	 n = n.toString('%s-%i').stripDash()

	 if ( k++ == 0 ) s  = n
	 else		 s += ',' + n
      }
   }

   document.menu.pname.value = s

   return s
}

function goHome()
{
   window.top.location.href = htmlhome
   return false
}

function viewTotal()
{
   yrlist = mkYearList()
   nmlist = mkNameList()

//   alert("viewTotal: '" + yrlist + "', '" + nmlist + "'" )

   document.menu.kind.value = 'total'
   document.menu.target     = 'body'
   document.menu.submit()

   return false
}

function viewTotalCDF()
{
   yrlist = mkYearList()
   nmlist = mkNameList()

//   alert("viewList: '" + yrlist + "', '" + nmlist + "'" )

   document.menu.kind.value = 'totalCDF'
   document.menu.target     = 'body'
   document.menu.submit()

   return false
}

function viewYear()
{
   yrlist = mkYearList()
   nmlist = mkNameList()

//   alert("viewYear: '" + yrlist + "', '" + nmlist + "'" )

   document.menu.kind.value = 'year'
   document.menu.target     = 'body'
   document.menu.submit()

   return false
}

function viewList()
{
   yrlist = mkYearList()
   nmlist = mkNameList()

//   alert("viewList: '" + yrlist + "', '" + nmlist + "'" )

   document.menu.kind.value = 'list'
   document.menu.target     = 'body'
   document.menu.submit()

   return false
}

/*
function viewHelp()
{
   parent.body.location = 'help-nl.html'
   return false
}
*/

function mouseover(n)
{
//alert( 'mouseover' );

   // Iexplore cannot use re '\.gif$' in replace; -> don't use gif as directory part!!.

   document.images[n].src = document.images[n].src.replace('\.gif', '!.gif' );
   return false
}

function mouseout(n)
{
//alert( 'mouseout' );

   // Iexplore cannot use re '\.gif$' in replace; -> don't use gif as directory part!!.

   document.images[n].src = document.images[n].src.replace('!\.gif', '.gif' );
   return false
}

/*
 * startNew - pop-up the new entry screen.
 */

function startNewEntry()
{
   if ( null == newEntryWindow || newEntryWindow.closed )
   {
      /*
       * use two-step approach to circumvent bug in Navigator 2.0 on Unix/Macintosh platforms.
       */
/*
      newEntryWindow = window.open( "", "ELD_verlofregistratie_entry",
	 "dependent=yes,toolbar=no,directories=no,menubar=no,scrollbars,resizable=yes,width=730,height=310");

      newEntryWindow.location = "register.html";
*/
//	document.menu.target = ''
      newEntryWindow = window.open( "register.html", "ELD_verlofregistratie_entry",
	 "dependent=yes,toolbar=no,directories=no,menubar=no,scrollbars,resizable=yes,width=730,height=310");
   }

   return focusWindow( newEntryWindow );
}

/*
 * startHelp - pop-up the helpscreen.
 */

function startHelp()
{
   if ( null == helpWindow || helpWindow.closed )
   {
      helpWindow = window.open( help, "verlofregistratie_help",
	 "dependent=yes,toolbar=no,directories=no,menubar=no,scrollbars,resizable=yes,width=550,height=600");
   }

   focusWindow( helpWindow );

   return false;
}

/*
 * focusWindow - focus window after checking that it exists and is not closed already.
 */

function focusWindow( hwnd )
{
   if ( null != hwnd && !hwnd.closed )
      hwnd.focus();

   return false;
}

/*
 * closeWindow - close window after checking that it exists and is not closed already.
 */

function closeWindow( hwnd )
{
   if ( null != hwnd && !hwnd.closed )
      hwnd.close();

   return false;
}

/*
 * end of file
 */

==> verlof-0.5.0.tar.gz: verlof-0.5.0/src/menu.js <==
/*
 * menu.js - menubar JavaScript.
 *
 * Verlof Web application
 *
 * Copyright (c) 2002, by Leiden University.
 * verlof is free software.  See the file Copying for copying permission.
 *
 * $Revision: 1.5 $
 * $Date: 2003-10-07 14:40:53+02 $
 * $Source: \\\\einstein.eld.LeidenUniv.nl\\homes\\myprojects\\RCS\\H\\myprojects\\fsc\\prj\\verlof\\src\\menu.js,v $
 * %Author: M.J. Moene %
 */

/*
 * $Header: \\\\einstein.eld.LeidenUniv.nl\\homes\\myprojects\\RCS\\H\\myprojects\\fsc\\prj\\verlof\\src\\menu.js,v 1.5 2003-10-07 14:40:53+02 moene Exp $
 *
 * $Log: menu.js,v $
 * Revision 1.5  2003-10-07 14:40:53+02  moene
 * added function doNothing().
 * added comments.
 *
 * Revision 1.4  2003-01-29 09:19:25+01  moene
 * <>
 *
 * Revision 1.3  2003/01/06 11:31:51  moene
 * namefield now also accepts accented letters [\xC0-\xFF].
 *
 * Revision 1.2  2002-12-12 15:59:46+01  moene
 * added more checking for names that can be handled from Menu namefield.
 *
 * Revision 1.1  2002/05/13 09:20:04  moene
 * Initial revision
 *
 */

var newEntryWindow = null;              // the new entry window
var helpWindow     = null;              // the help window

/*
 * for those that do not supply javascript:doNothing():
 */

function doNothing()
{
}

/*
 * initialize the menu:
 */

function initialize()
{
//alert( 'initialize' )
   document.menu.dbhost.value = dbhost
   document.menu.db.value     = db
   document.menu.sort.value   = 'n+1-'    // name ascending, date1 descending
   document.menu.year.value   = (new Date).getFullYear()

   document.menu.name.value   = getCookie( 'name' )

   document.menu.target       = 'body'
   document.menu.method       = 'post'
   document.menu.action       = submitView
//   document.menu.action     = '/cgi-bin/printenv'

   return false;
}

/*
 * finalize the menu: close new entry window, if there
 */

function finalize()
{
//alert( 'finalize' );

   closeWindow( newEntryWindow );

   return false;
}

/*
 * create the list of years from the menu year field:
 * - (empty), whitespace, '*' -> ""
 * - a b, c;d : e             -> a,b,c,d,e
 */

function mkYearList()
{
   yrlist = document.menu.year.value.split(/[ ,;:]/)

   var s = new String()

   // empty, or '*' acts as wildcard -> return empty string

   if ( yrlist[0].match( /^$|^[\s\*]+$/ ) )
      return s
   else
      return s.join( yrlist, ',' )
}

/*
 * create the list of names from the menu name field:
 * - (empty), whitespace, '*' -> ""
 * - i name, an other -> Name-I,Other-AN
 */

function mkNameList()
{
//return 'a,b'

   nmlist = document.menu.name.value.split(/[,;:]/)

   var s = new String()

   // empty, whitespace, or '*' acts as wildcard -> return empty string

   if ( !nmlist[0].match( /^[\s]*$|\*/ ) )
   {
      var k = 0
      for ( var i = 0; i < nmlist.length; i++ ) {

         // skip if name cannot be handled by class Name
         if ( !nmlist[i].match( /^[\s]*[a-zA-Z\xC0-\xFF\(\)\ \._-]+$/ ) )
            continue

         n = new Name( nmlist[i] )
         n = n.toString('%s-%i').stripDash()

         if ( k++ == 0 ) s  = n
         else            s += ',' + n
      }
   }

   document.menu.pname.value = s

   return s
}

/*
 * display home page:
 */

function goHome()
{
   window.top.location.href = htmlhome
   return false
}

/*
 * display year total view:
 */

function viewTotal()
{
   yrlist = mkYearList()
   nmlist = mkNameList()

//   alert("viewTotal: '" + yrlist + "', '" + nmlist + "'" )

   document.menu.kind.value = 'total'
   document.menu.target     = 'body'
   document.menu.submit()

   return false
}

/*
 * display year total view as a comma separated list:
 */

function viewTotalCDF()
{
   yrlist = mkYearList()
   nmlist = mkNameList()

//   alert("viewList: '" + yrlist + "', '" + nmlist + "'" )

   document.menu.kind.value = 'totalCDF'
   document.menu.target     = 'body'
   document.menu.submit()

   return false
}

/*
 * display year view:
 */

function viewYear()
{
   yrlist = mkYearList()
   nmlist = mkNameList()

//   alert("viewYear: '" + yrlist + "', '" + nmlist + "'" )

   document.menu.kind.value = 'year'
   document.menu.target     = 'body'
   document.menu.submit()

   return false
}

/*
 * display list view:
 */

function viewList()
{
   yrlist = mkYearList()
   nmlist = mkNameList()

//   alert("viewList: '" + yrlist + "', '" + nmlist + "'" )

   document.menu.kind.value = 'list'
   document.menu.target     = 'body'
   document.menu.submit()

   return false
}

/*
function viewHelp()
{
   parent.body.location = 'help-nl.html'
   return false
}
*/

/*
 * on event mouse over image n, replace image.gif with image!.gif (selected):
 */

function mouseover(n)
{
//alert( 'mouseover' );

   // Iexplore cannot use re '\.gif$' in replace; -> don't use gif as directory part!!.

   document.images[n].src = document.images[n].src.replace('\.gif', '!.gif' );
   return false
}

/*
 * on event mouse out image n, replace image!.gif with image.gif (unselected):
 */

function mouseout(n)
{
//alert( 'mouseout' );

   // Iexplore cannot use re '\.gif$' in replace; -> don't use gif as directory part!!.

   document.images[n].src = document.images[n].src.replace('!\.gif', '.gif' );
   return false
}

/*
 * pop-up the new entry screen:
 */

function startNewEntry()
{
   if ( null == newEntryWindow || newEntryWindow.closed )
   {
      /*
       * use two-step approach to circumvent bug in Navigator 2.0 on Unix/Macintosh platforms.
       */
/*
      newEntryWindow = window.open( "", "ELD_verlofregistratie_entry",
         "dependent=yes,toolbar=no,directories=no,menubar=no,scrollbars,resizable=yes,width=730,height=310");

      newEntryWindow.location = "register.html";
*/
//      document.menu.target = ''
      newEntryWindow = window.open( "register.html", "ELD_verlofregistratie_entry",
         "dependent=yes,toolbar=no,directories=no,menubar=no,scrollbars,resizable=yes,width=730,height=310");
   }

   return focusWindow( newEntryWindow );
}

/*
 * pop-up the helpscreen:
 */

function startHelp()
{
   if ( null == helpWindow || helpWindow.closed )
   {
      helpWindow = window.open( help, "verlofregistratie_help",
         "dependent=yes,toolbar=no,directories=no,menubar=no,scrollbars,resizable=yes,width=550,height=600");
   }

   focusWindow( helpWindow );

   return false;
}

/*
 * focus window after checking that it exists and is not closed already:
 */

function focusWindow( hwnd )
{
   if ( null != hwnd && !hwnd.closed )
      hwnd.focus();

   return false;
}

/*
 * close window after checking that it exists and is not closed already:
 */

function closeWindow( hwnd )
{
   if ( null != hwnd && !hwnd.closed )
      hwnd.close();

   return false;
}

/*
 * end of file
 */
